summaryrefslogtreecommitdiff
path: root/src/tr.c
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1995-01-17 13:57:22 +0000
committerJim Meyering <jim@meyering.net>1995-01-17 13:57:22 +0000
commit41fc246374973071b5404bc46fd7296dd3eaa835 (patch)
tree6ba90f400e2a705745d26d2301eadead579f60d1 /src/tr.c
parentcfaf788606e85ad2fa0370e55e0b4eb7e9be6881 (diff)
downloadcoreutils-41fc246374973071b5404bc46fd7296dd3eaa835.tar.xz
Don't use `legal' when you mean `valid'.
Diffstat (limited to 'src/tr.c')
-rw-r--r--src/tr.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/tr.c b/src/tr.c
index 3dea1d3a3..891294393 100644
--- a/src/tr.c
+++ b/src/tr.c
@@ -155,7 +155,7 @@ struct List_element
to work with: a linked list of constructs (struct List_element).
Each Spec_list structure also encapsulates various attributes of
the corresponding argument string. The attributes are used mainly
- to verify that the strings are legal in the context of any options
+ to verify that the strings are valid in the context of any options
specified (like -s, -d, or -c). The main exception is the member
`tail', which is first used to construct the list. After construction,
it is used by get_next to save its state when traversing the list.
@@ -1219,7 +1219,7 @@ card_of_complement (s)
}
/* Gather statistics about the spec-list S in preparation for the tests
- in validate that determine the legality of the specs. This function
+ in validate that determine the consistency of the specs. This function
is called at most twice; once for string1, and again for any string2.
LEN_S1 < 0 indicates that this is the first call and that S represents
string1. When LEN_S1 >= 0, it is the length of the expansion of the
@@ -1409,7 +1409,7 @@ string2_extend (s1, s2)
/* Die with an error message if S1 and S2 describe strings that
are not valid with the given command line switches.
- A side effect of this function is that if a legal [c*] or
+ A side effect of this function is that if a valid [c*] or
[c*0] construct appears in string2, it is converted to [c*n]
with a value for n that makes s2->length == s1->length. By
the same token, if the --truncate-set1 option is not
@@ -1760,7 +1760,7 @@ main (argc, argv)
non_option_args = argc - optind;
translating = (non_option_args == 2 && !delete);
/* Change this test if it is legal to give tr no options and
no args at all. POSIX doesn't specifically say anything
either way, but it looks like they implied it's invalid
by omission. If you want to make tr do a slow imitation
@@ -1760,7 +1760,7 @@ main (argc, argv)
non_option_args = argc - optind;
translating = (non_option_args == 2 && !delete);
- /* Change this test if it is legal to give tr no options and
+ /* Change this test if it is valid to give tr no options and
no args at all. POSIX doesn't specifically say anything
either way, but it looks like they implied it's invalid